# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/wahid/test_general/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/wahid/test_general/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Wahid\\TestGeneral\\": "packages/wahid/test_general/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Wahid\TestGeneral\Providers\TestGeneralServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'TestGeneral'  => Wahid\TestGeneral\Facades\TestGeneral::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Wahid\\TestGeneralTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Wahid\TestGeneral\Providers\TestGeneralServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Wahid\TestGeneral\Providers\TestGeneralServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Wahid\TestGeneral\Providers\TestGeneralServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/test_general/{modulename}

**User**

    http://path-to-route-folder/user/test_general/{modulename}

**Public**

    http://path-to-route-folder/test_generals


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/test_general/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/test_general/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/test_general/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/test_general/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/test_general/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/test_general/{modulename}/{slug}
    METHOD: GET