<?php

namespace Wahid\TestGeneral\Providers;

use Illuminate\Support\ServiceProvider;

class TestGeneralServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'test_general');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'test_general');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerTestGeneral();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerTestGeneral()
    {
        $this->app->bind('test_general', function($app) {
            return new TestGeneral($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('TestGeneral', 'Lavalite\TestGeneral\Facades\TestGeneral');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('wahid.test_general', function ($app) {
            return $this->app->make('Wahid\TestGeneral\TestGeneral');
        });

                // Bind Status to repository
        $this->app->bind(
            'Wahid\TestGeneral\Interfaces\StatusRepositoryInterface',
            \Wahid\TestGeneral\Repositories\Eloquent\StatusRepository::class
        );

        $this->app->register(\Wahid\TestGeneral\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Wahid\TestGeneral\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and test_general's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'wahid.test_general'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeTestGeneral::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['wahid.test_general'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('wahid/test_general.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/test_general')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/test_general')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
